/*
 *	libetm-0.4 / misc.h - Copyright (C) Emmanuel Thomas-Maurin 2008-2011
 * 	<manutm007@gmail.com>
 *
 *	- misc functions -
 *
 * 	This program is free software: you can redistribute it and/or modify
 * 	it under the terms of the GNU General Public License as published by
 * 	the Free Software Foundation, either version 3 of the License, or
 * 	(at your option) any later version.
 *
 * 	This program is distributed in the hope that it will be useful,
 * 	but WITHOUT ANY WARRANTY; without even the implied warranty of
 * 	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * 	GNU General Public License for more details.
 *
 * 	You should have received a copy of the GNU General Public License
 * 	along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef INC_LIBETM_MISC_H
#define INC_LIBETM_MISC_H

const char *lib_version(unsigned int);
int question(const char *);
#endif /* INC_LIBETM_MISC_H */
